@@ -75,7 +75,9 @@ SeasidePerson *SeasidePersonAttached::selfPerson() const
 {
     if (SeasideCache::CacheItem *item = SeasideCache::itemById(SeasideCache::selfContactId())) {
         if (!item->itemData) {
-            item->itemData = new SeasidePerson(&item->contact, (item->contactState == SeasideCache::ContactComplete), SeasideCache::instance());
+            item->itemData = new SeasidePerson(&item->contact,
+                                               item->contactState == SeasideCache::ContactComplete,
+                                               SeasideCache::instance());
         }
 
         return static_cast<SeasidePerson *>(item->itemData);
@@ -2211,7 +2213,7 @@ void SeasidePerson::emitChangeSignals()
 }
 
 /*!
-  \qmlmethod void Person::ensureComplete
+  \qmlmethod void Person::ensureComplete()
 */
 void SeasidePerson::ensureComplete()
 {
@@ -2221,7 +2223,7 @@ void SeasidePerson::ensureComplete()
 }
 
 /*!
-  \qmlmethod object Person::contactData
+  \qmlmethod object Person::contactData()
 */
 QVariant SeasidePerson::contactData() const
 {
